==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/TreemapNodeStyleMappingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodeStyleDescriptionMetadata } from "./TreemapNodeStyleDescriptionMetadata";
import { TreemapNodeStyleMappingDescription } from "./TreemapNodeStyleMappingDescription";
/**
 * @hidden
 */
var TreemapNodeStyleMappingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreemapNodeStyleMappingDescriptionMetadata, _super);
    function TreemapNodeStyleMappingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodeStyleMappingDescriptionMetadata.b = function (a) {
        if (TreemapNodeStyleMappingDescriptionMetadata.a == null) {
            TreemapNodeStyleMappingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodeStyleMappingDescriptionMetadata.c(TreemapNodeStyleMappingDescriptionMetadata.a);
        }
        if (a.k(TreemapNodeStyleMappingDescriptionMetadata.a)) {
            return;
        }
        a.ab(TreemapNodeStyleMappingDescriptionMetadata.a);
    };
    TreemapNodeStyleMappingDescriptionMetadata.c = function (a) {
        TreemapNodeStyleDescriptionMetadata.c(a);
        a.item("TargetType", "ExportedType:string:TreemapNodeStyleMappingTargetType");
        a.item("TargetType@names", "All;Parent;Child");
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("Value", "Unknown");
        a.item("MappingMode", "ExportedType:string:TreemapValueMappingMode");
        a.item("MappingMode@names", "Sum;Value;CustomValue");
    };
    TreemapNodeStyleMappingDescriptionMetadata.d = function (a) {
        TreemapNodeStyleMappingDescriptionMetadata.b(a);
        a.ad("TreemapNodeStyleMapping", function () { return new TreemapNodeStyleMappingDescription(); });
        a.ac("TreemapNodeStyleMapping", TreemapNodeStyleMappingDescriptionMetadata.a);
    };
    TreemapNodeStyleMappingDescriptionMetadata.$t = markType(TreemapNodeStyleMappingDescriptionMetadata, 'TreemapNodeStyleMappingDescriptionMetadata');
    TreemapNodeStyleMappingDescriptionMetadata.a = null;
    return TreemapNodeStyleMappingDescriptionMetadata;
}(Base));
export { TreemapNodeStyleMappingDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/TreemapNodeStyleMappingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodeStyleDescriptionMetadata } from "./TreemapNodeStyleDescriptionMetadata";
import { TreemapNodeStyleMappingDescription } from "./TreemapNodeStyleMappingDescription";
/**
 * @hidden
 */
var TreemapNodeStyleMappingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreemapNodeStyleMappingDescriptionMetadata, _super);
    function TreemapNodeStyleMappingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodeStyleMappingDescriptionMetadata.b = function (a) {
        if (TreemapNodeStyleMappingDescriptionMetadata.a == null) {
            TreemapNodeStyleMappingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodeStyleMappingDescriptionMetadata.c(TreemapNodeStyleMappingDescriptionMetadata.a);
        }
        if (a.k(TreemapNodeStyleMappingDescriptionMetadata.a)) {
            return;
        }
        a.ac(TreemapNodeStyleMappingDescriptionMetadata.a);
    };
    TreemapNodeStyleMappingDescriptionMetadata.c = function (a) {
        TreemapNodeStyleDescriptionMetadata.c(a);
        a.item("TargetType", "ExportedType:string:TreemapNodeStyleMappingTargetType");
        a.item("TargetType@names", "All;Parent;Child");
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("Value", "Unknown");
        a.item("MappingMode", "ExportedType:string:TreemapValueMappingMode");
        a.item("MappingMode@names", "Sum;Value;CustomValue");
    };
    TreemapNodeStyleMappingDescriptionMetadata.d = function (a) {
        TreemapNodeStyleMappingDescriptionMetadata.b(a);
        a.ae("TreemapNodeStyleMapping", function () { return new TreemapNodeStyleMappingDescription(); });
        a.ad("TreemapNodeStyleMapping", TreemapNodeStyleMappingDescriptionMetadata.a);
    };
    TreemapNodeStyleMappingDescriptionMetadata.$t = markType(TreemapNodeStyleMappingDescriptionMetadata, 'TreemapNodeStyleMappingDescriptionMetadata');
    TreemapNodeStyleMappingDescriptionMetadata.a = null;
    return TreemapNodeStyleMappingDescriptionMetadata;
}(Base));
export { TreemapNodeStyleMappingDescriptionMetadata };
